## cdist-type__install_stage(7)

### Steven Armstrong

`<steven-cdist--@--armstrong.cc>`

## 1. NAME

cdist-type__install_stage - download and unpack a stage file

## 2. DESCRIPTION

Downloads a operating system stage using curl and unpacks it to /target using tar. The stage tarball is expected to be gzip compressed.

## 3. REQUIRED PARAMETERS

uri
  The uri from which to fetch the tarball. Can be anything understood by curl, e.g: http://path/to/stage.tgz tftp:///path/to/stage.tgz file:///local/path/stage.tgz

## 4. OPTIONAL PARAMETERS

target
  where to unpack the tarball to. Defaults to /target.

## 5. BOOLEAN PARAMETERS

insecure
  run curl in insecure mode so it does not check the servers ssl certificate

## 6. EXAMPLES

    __install_stage --uri tftp:///path/to/stage.tgz
    __install_stage --uri http://path/to/stage.tgz --target /mnt/foobar
    __install_stage --uri file:///path/to/stage.tgz --target /target
    __install_stage --uri https://path/to/stage.tgz --target /mnt/foobar --insecure

## 7. SEE ALSO

- cdist-type(7)

## 8. COPYING

Copyright (C) 2011 - 2013 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).